@@ -6,6 +6,7 @@ from solitude import TOOL_NAME
 from solitude.slurmjob import SlurmJob
 from solitude.cache import Cache
 from solitude import hookimpl
+from solitude.utils.ssh import SSHClient
 
 
 def md5(s) -> str:
@@ -16,15 +17,15 @@ class CommandBase(object):
     def __init__(
         self, cmd: str, plugin: hookimpl, cache: Optional[Cache] = None
     ):
-        self.logger = logging.getLogger(type(self).__name__)
-        self._plugin = plugin
-        self.cmd = cmd.strip()
-        self.cache = cache
-        self.hash = md5(
+        self.logger: logging.Logger = logging.getLogger(type(self).__name__)
+        self._plugin: hookimpl = plugin
+        self.cmd: str = cmd.strip()
+        self.cache: Optional[Cache] = cache
+        self.hash: str = md5(
             self.get_plugin_short_name()
             + self._plugin.get_command_hash(self.cmd)
         )
-        self.job_info = None
+        self.job_info: Optional[SlurmJob] = None
         self._set_basic_job_info_from_cache()
         self._state: Dict[str, Any] = {}
         self.errors: List[str] = []
@@ -34,8 +35,8 @@ class CommandBase(object):
             f"{TOOL_NAME}_", ""
         )
 
-    def update(self):
-        self.update_job_info()
+    def update(self, ssh_client: SSHClient):
+        self.update_job_info(ssh_client=ssh_client)
         self.update_state()
         self.update_errors()
 
@@ -51,10 +52,15 @@ class CommandBase(object):
             entry = self.cache[self.hash]
             self.job_info = entry
 
-    def update_job_info(self):
+    def update_job_info(self, ssh_client: SSHClient):
         if self.cache is not None and self.hash in self.cache:
             try:
-                job_info = SlurmJob(jobid=self.cache[self.hash].id)
+                cached_job = self.cache[self.hash]
+                if not isinstance(cached_job, SlurmJob):
+                    raise ValueError(
+                        f"Unexpected Cached object found! Should be of type SlurmJob! Found: {type(cached_job)}"
+                    )
+                job_info = SlurmJob(ssh_client=ssh_client, jobid=cached_job.id)
                 job_info.update()
                 self.job_info = job_info
             except ValueError:
@@ -100,16 +106,14 @@ class CommandBase(object):
 
     def __str__(self) -> str:
         self._errors: List[str] = []
-        url, priority = "-", ""
+        priority = ""
         if self.job_info is not None:
-            url = self.job_info.get_log_url()
             if self.is_running() and self.job_info.priority == "high":
                 priority = "H*"
-        return "{status:4}{priority:2} {url:28} {plugin:10} {tag} {errors}".format(
+        return "{status:4}{priority:2} {plugin:10} {tag} {errors}".format(
             plugin=self.get_plugin_short_name(),
             tag=self.get_job_info_str(),
             status=self.get_job_status_str(),
-            url=url,
             priority=priority,
             errors=f'!!ERRORS: {" ".join(self.errors)}!!'
             if self.is_erroneous()
@@ -119,18 +123,12 @@ class CommandBase(object):
     @staticmethod
     def header_str() -> str:
         return (
-            "id  {status:6} {url:28} {plugin:10} {info}".format(
-                plugin="plugin",
-                info="job_info",
-                status="status",
-                url="log_url",
+            "id  {status:6} {plugin:10} {info}".format(
+                plugin="plugin", info="job_info", status="status"
             )
             + "\n"
-            + "--  {status:6} {url:28} {plugin:10} {info}".format(
-                plugin="------",
-                info="--------",
-                status="------",
-                url="-------",
+            + "--  {status:6} {plugin:10} {info}".format(
+                plugin="------", info="--------", status="------",
             )
         )
 
