@@ -8,8 +8,6 @@ import appdirs
 
 from solitude import TOOL_AUTHOR, TOOL_NAME
 
-__config = None
-
 
 def get_existing_filepath(
     filename: str, valid_dirs: List[Path], allow_non_existing: bool = False
@@ -177,10 +175,3 @@ class Config(object):
                 self.plugins = cfg["plugins"]
             else:
                 self.plugins = []
-
-
-def get_config() -> Config:
-    global __config
-    if __config is None:
-        __config = Config()
-    return __config
